﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

using C1.C1Preview;
using C1.Win.C1Preview;

namespace PageBreakTest
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void button1_Click(object sender, EventArgs e)
        {
            using (C1PrintPreviewDialog d = new C1PrintPreviewDialog())
            {
                d.ShowDialog();
            }
        }

        /// <summary>
        /// Creates sample C1PrintDocument that will optionally add a page if owner C1MultiDocument has odd number of pages (if 'evenPages' is true).
        /// </summary>
        /// <param name="caption">Document caption.</param>
        /// <param name="lineCount">Count of lines in the document.</param>
        /// <param name="evenPages">If <b>true</b> then the document add empty page if owner C1MultiDocument has odd number of pages.</param>
        /// <returns>The created document.</returns>
        private C1PrintDocument CreateDoc(string caption, int lineCount, bool evenPages)
        {
            C1PrintDocument doc = new C1PrintDocument();

            // initialize simple page footer that will display page number / count of pages
            doc.PageLayout.PageFooter = new RenderText("[PageNo] / [PageCount]"); ;
            doc.PageLayout.PageFooter.Style.Borders.Top = LineDef.Default;
           
            if (evenPages)
            {
                // add RenderEmpty object that will force adding of empty page to document
                // so that it contains an even number of pages:
                RenderEmpty re = new RenderEmpty();
                re.ObjectResolvedScript =
                    "if MultiDocument.PageCount mod 2 = 0 then\r\n" +
                    "   Dim lc As LayoutChangeNewPage = New LayoutChangeNewPage()\r\n" +
                    "   lc.PageLayout = New PageLayout()\r\n" +
                    "   lc.PageLayout.Pageheader = New RenderEmpty()\r\n" +
                    "   lc.PageLayout.PageFooter = New RenderEmpty()\r\n" +
                    "   Document.Body.Children(RenderObject.IndexInOwner + 1).LayoutChangeAfter = lc\r\n" +
                    "else\r\n" +
                    "   Document.Body.Children(RenderObject.IndexInOwner + 1).LayoutChangeAfter = Nothing\r\n" +
                    "end if";
                doc.Body.Children.Add(re);
                doc.Body.Children.Add(new RenderEmpty());
            }

            // Create document's caption
            RenderText rtCaption = new RenderText();
            rtCaption.Text = caption;
            rtCaption.Style.Font = new Font("Tahoma", 20);
            rtCaption.Style.Borders.Bottom = new LineDef("1mm", Color.Blue);
            rtCaption.Style.Spacing.Bottom = "5mm";
            doc.Body.Children.Add(rtCaption);

            // generate document body
            for (int i = 0; i < lineCount; i++)
            {
                RenderText rt = new RenderText();
                rt.Text = string.Format("Line {0}", i);
                doc.Body.Children.Add(rt);
            }


            return doc;
        }

        private void button3_Click(object sender, EventArgs e)
        {
            C1MultiDocument md = new C1MultiDocument();
            md.Items.Add(CreateDoc("Coversheet", 10, false));
            md.Items.Add(CreateDoc("TOC", 10, true));
            md.Items.Add(CreateDoc("Code", 20, true));
            md.Items.Add(CreateDoc("Code", 20, true));
            md.Items.Add(CreateDoc("Code", 12, true));
            md.Items.Add(CreateDoc("Index", 17, true));
            md.Generate();

            using (C1PrintPreviewDialog d = new C1PrintPreviewDialog())
            {
                d.Document = md;
                d.ShowDialog();
            }
        }
    }
}
